<?php
/* (c) 2001 Marco Pratesi <pratesi@telug.it> */
$t = new Template();
$t->set_file(array("page" => "templates/header.ihtml"));
include ("$CFG->localelangdir" . "/global-common.inc.php");
include ("$CFG->localelangdir" . "/global-admin.inc.php");
$t->set_var("wwwroot", $CFG->wwwroot);
$t->set_var("images", $CFG->images);
$t->set_var("firstpage", $CFG->firstpage);
$t->set_var(array(
	"DOC_TITLE"			=> ov($t->get_var($DOC_TITLE)),
	"session_user_customername"	=> o($SESSION["user"]["firstname"] . " " . $SESSION["user"]["lastname"])
));
$t->set_block("page", "brand_used_header", "brand_used_header_blck");
$t->set_var("brand_used_header_blck", "");
if($SESSION["brand_used"])
	$t->parse("brand_used_header_blck", "brand_used_header", true);
$t->set_block("page", "iva_used_header", "iva_used_header_blck");
$t->set_var("iva_used_header_blck", "");
if($SESSION["iva_used"])
	$t->parse("iva_used_header_blck", "iva_used_header", true);
$t->pparse("out", "page");
?>
